Learn R Programming

PAMscapes (version 0.15.0)

loadMantaNc: Load MANTA NetCDF File

Description

Reads in hybrid millidecade data from a MANTA NetCDF output file and formats it into the dataframe format required for use in other PAMscapes functions

Usage

loadMantaNc(x, keepQuals = c(1), keepEffort = TRUE)

Value

a dataframe with first column UTC and other columns named HMD_Frequency

Arguments

x

path to .nc file

keepQuals

quality flag values to keep. Accepts vector of integers from (1, 2, 3, 4) corresponding to flag labels "Good", "Not evaluated/Unknown", "Compromised/Questionable", and "Unusable/Bad". HMD levels for points with data quality flags outside of keepQuals will be marked as NA.

keepEffort

if TRUE or FALSE, a logical flag whether or not to keep the effort information with the outputs (number of seconds per minute). If a numeric value, then any minutes with an effort value less than keepEffort will be removed (e.g. 50 will remove minutes with less than 50 seconds of effort)

Author

Taiki Sakai [email protected]

Examples

Run this code
# no sample NetCDF provided (too large)
# \donttest{
manta <- loadMantaNc('MANTA.nc')
# }

Run the code above in your browser using DataLab