View source: R/plotPolarDetections.R
| plotPolarDetections | R Documentation |
Plots detection data in a polar plot where the circular (angular) axis is either the hour of day or month of the year
plotPolarDetections(
x,
bin = c("days/month"),
detectedValue = NULL,
quantity = c("count", "mean", "effort", "percentEffort", "percentTotal"),
group = c("species", "deployment"),
facet = NULL,
effort = NULL,
matchEffort = TRUE,
title = NULL,
returnData = FALSE,
verbose = TRUE
)
x |
dataframe of data loaded with loadDetectionData |
bin |
character specification of the radial and circular (angular) dimensions of the plot in the form "bin1/bin2", where "bin1" is one of "detection", "hour", or "day", and "bin2" is one of "hour" or "month". "bin1" is the units of the radial axis, and "bin2" is the unit of the circular axis. If "bin1" is "detection", then each row is treated as a distinct instantaneous detection, otherwise calls are binned using binDetectionData. |
detectedValue |
values in the "detectedFlag" column of |
quantity |
character indicating what type of quantity to plot. "count"
plots total detections, "mean" plots average detections across |
group |
a vector of name(s) of columns in |
facet |
optional name of column to facet output plot by |
effort |
Not relevant for |
matchEffort |
if |
title |
optional title for plot |
returnData |
if |
verbose |
logical flag to print messages |
a ggplot object
Taiki Sakai taiki.sakai@noaa.gov
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.