View source: R/runDailyLTSAReview.R
| runDailyLTSAReview | R Documentation |
Run Daily Soundscape LTSA Data Review Shiny App
runDailyLTSAReview(file, plotQuality = FALSE)
file |
either a folder containing NetCDF soundscape files or a single file |
plotQuality |
logical flag whether or not to plot the matrix of data quality flags. This greatly increases the load time for each file. |
Launches a Shiny app that allows users to manually review LTSA style plots of soundscape NetCDF data. Users can draw annotations on the LTSA plot and export these annotations as a CSV file. Users can additionally mark selected areas with the 1-4 standard quality flags.
nothing, just runs the app
Taiki Sakai taiki.sakai@noaa.gov
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.