runDetLoadHelper: Run Detection Data Loading Helper App

View source: R/runDetLoadHelper.R

runDetLoadHelperR Documentation

Run Detection Data Loading Helper App

Description

Runs a Shiny app that allows users to interactively find the proper parameters to load a detection dataset using loadDetectionData. As of 0.14.0

Usage

runDetLoadHelper(data = NULL)

Arguments

data

file path to a CSV file containing detection data

Author(s)

Taiki Sakai taiki.sakai@noaa.gov

Examples

if(interactive()) {
  detFile <- system.file('extdata/detectionExample.csv', package='PAMscapes')
  runDetLoadHelper(detFile)
}


PAMscapes documentation built on Oct. 3, 2026, 1:06 a.m.