View source: R/runDetectionExplorer.R
| runDetectionExplorer | R Documentation |
Runs a Shiny app that allows users to interactively find the proper parameters to load a detection dataset using loadDetectionData and explore plots for detection data
runDetectionExplorer(data = NULL)
data |
file path to a CSV file containing detection data or a dataframe |
Taiki Sakai taiki.sakai@noaa.gov
if(interactive()) {
detFile <- system.file('extdata/detectionExample.csv', package='PAMscapes')
runDetectionExplorer(detFile)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.