View source: R/addDataQuality.R
| addDataQuality | R Documentation |
Add or modify the existing data quality matrix data
in a PyPam (or similar) hybrid millidecade NetCDF output. This
data adds or modifies the "quality_flag" variable of a NetCDF
file, which is a matrix of numbers 1,2,3, or 4 that is the same
dimensions as the hybrid millidecade outputs. The input NetCDF files
are modified unless preview=TRUE
addDataQuality(
x,
annotation = NULL,
platformColumn = NULL,
updateUnknown = FALSE,
preview = FALSE,
plot = FALSE,
reset = FALSE,
verbose = FALSE
)
formatDQDf(annotation)
x |
one or more NetCDF files or a folder containing NetCDF files.
If |
annotation |
a dataframe of annotations specifying the time-frequency
bounds and quality flags to be changed. Columns for time bounds must
be called |
platformColumn |
NetCDF files should contain a "platform" global attribute,
this can be used to specify that certain rows of |
updateUnknown |
if |
preview |
if |
plot |
if |
reset |
if |
verbose |
logical flag to show or hide some messages |
TRUE or FALSE to indicate whether or not any
annotations were applied. If x is multiple files or a folder of
files, the returned vector has names equal to the file names
Taiki Sakai taiki.sakai@noaa.gov
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.