| plotPSD | R Documentation |
Plots the distribution of summarised sound levels across frequency, either as lines of quantile levels or a heatmap showing the full distribution. Multiple PSD sources can be combined and plotted as long as they have identical frequency levels.
plotPSD(
x,
style = c("quantile", "density"),
scale = c("log", "linear"),
q = 0.5,
color = "black",
lwd = 1,
quantileBorder = TRUE,
borderLwd = 0.5,
alpha = 0.1,
linetype = 1,
freqRange = NULL,
dbRange = NULL,
dbInt = 1,
densityRange = NULL,
units = "dB re: 1uPa^2/Hz",
cmap = viridis_pal()(25),
by = NULL,
referenceLevel = NULL,
showNObs = TRUE,
facet = NULL,
ncol = NULL,
title = NULL,
returnData = FALSE,
progress = TRUE
)
prepPSDData(
x,
freqRange = NULL,
style = c("density", "quantile"),
by = NULL,
dbInt = 1,
compression = 10000,
progress = TRUE
)
x |
a dataframe or file path or vector of file paths |
style |
character specifying plot style to create, either "quantile", "density", or a vector with both |
scale |
scale to use for frequency axis, one of "log" or "linear" |
q |
quantile to plot |
color |
color for quantile. Can be a named vector with names corresponding
to values in |
lwd |
line width for median line in quantile plot |
quantileBorder |
logical flag to show a line border at quantile boundary instead of just shading |
borderLwd |
line width for border lines if |
alpha |
alpha level for the ribbon shading when plotting a quantile |
linetype |
line type to use for lines, multiple values can be provided
for different levels if |
freqRange |
range of frequencies to plot |
dbRange |
range of dB values to plot |
dbInt |
bin interval size for density plot |
densityRange |
optional range of values for density color scale |
units |
units for dB axis of plot |
cmap |
color map to use for density plot |
by |
optional column to plot different quantile lines by, only affects
|
referenceLevel |
only used together with |
showNObs |
logical flag to show number of observations in plot legend
when using |
facet |
optional column to facet the plots by |
ncol |
number of columns to use when plotting with |
title |
optional title for plot |
returnData |
if |
progress |
logical flag to show progress bar |
compression |
no longer used |
a ggplot object
Taiki Sakai taiki.sakai@noaa.gov
psd <- loadSoundscapeData(system.file('extdata/PSDSmall.csv', package='PAMscapes'))
# Plotting only first 1000 columns for brevity
plotPSD(psd[1:1000], style='density')
plotPSD(psd[1:1000], style='quantile', q=.05)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.